@@ -32,7 +32,7 @@ convert_tcga <- function(x,
 
   dt <- load_data("tcga")
   if (is.null(dt)) {
-    warning("Failed converting the data.", immediate. = TRUE)
+    message("Failed converting the data.")
     return(invisible(NULL))
   }
   convert(dt, x, from, to, multiple)
